# project to monitor live boxes
This is a project based on hadoop cal data, provide user the ability to explore boxes status and build models
based on these data.

### Tutorials
http://10.176.5.126:9090/notebooks/cal_ai.ipynb
